from fobi.constants import SUBMIT_VALUE_AS_MIX

__title__ = 'fobi.contrib.plugins.form_elements.fields.' \
            'select_mptt_model_object.defaults'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = 'Copyright (c) 2014 Artur-2015 Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('IGNORED_MODELS', 'SUBMIT_VALUE_AS',)

IGNORED_MODELS = []

SUBMIT_VALUE_AS = SUBMIT_VALUE_AS_MIX
